Training
========
.. automodule:::: pykeen.training

Stochastic Local Closed World Assumption
----------------------------------------
.. autoclass:: pykeen.training.SLCWATrainingLoop
   :members:
   :inherited-members:

Local Closed World Assumption
-----------------------------
.. autoclass:: pykeen.training.LCWATrainingLoop
   :members:
   :inherited-members:

Base Classes
------------
.. autoclass:: pykeen.training.TrainingLoop
   :members:

Lookup
------
.. autofunction:: pykeen.training.get_training_loop_cls
